unit frameContact;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants, 
  FMX.Types, FMX.Graphics, FMX.Controls, FMX.Forms, FMX.Dialogs, FMX.StdCtrls,
  FMX.Controls.Presentation, FMX.Edit, System.Actions, FMX.ActnList;

type
  TContactFrame = class(TFrame)
    txtContact: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    txtEmail: TEdit;
    btnSave: TButton;
    alFrame: TActionList;
    actSave: TAction;
    actNew: TAction;
    actClear: TAction;
    btnNew: TButton;
    btnClear: TButton;
    procedure actClearExecute(Sender: TObject);
    procedure actNewExecute(Sender: TObject);
    procedure actSaveExecute(Sender: TObject);
  private
    FID: Integer;
    function GetContactName: String;
    function GetEmail: String;
    procedure SetContactName(const Value: String);
    procedure SetEmail(const Value: String);
    procedure SetID(const Value: Integer);
    procedure SubscribeMessages;
    { Private declarations }
  public
    constructor Create(AOwner: TComponent); override;
    { Public declarations }
    property ContactName : String read GetContactName write SetContactName;
    property Email: String read GetEmail write SetEmail;
    property ID: Integer read FID write SetID;
  end;

implementation

uses DMain, System.Messaging, BothSides.Entities, BothSides.Messages;

{$R *.fmx}

{ TContactFrame }

procedure TContactFrame.actClearExecute(Sender: TObject);
begin
  ContactName := '';
  Email := '';
end;

procedure TContactFrame.actNewExecute(Sender: TObject);
var Contact : TContact;
begin
  Contact.Name := ContactName;
  Contact.Email := Email;
  DMMain.MsgManager.SendMessage( Self, TNewContactAdd.Create( Contact ));
end;

procedure TContactFrame.actSaveExecute(Sender: TObject);
var Contact : TContact;
begin
  Contact.Id := ID;
  Contact.Name := ContactName;
  Contact.Email := Email;
  DMMain.MsgManager.SendMessage( Self, TContactChanged.Create( Contact ));
end;

constructor TContactFrame.Create(AOwner: TComponent);
begin
  inherited;
  SubscribeMessages;
end;

function TContactFrame.GetContactName: String;
begin
  Result := txtContact.Text;
end;

function TContactFrame.GetEmail: String;
begin
  Result := txtEmail.Text;
end;

procedure TContactFrame.SetContactName(const Value: String);
begin
  txtContact.Text := Value;
end;

procedure TContactFrame.SetEmail(const Value: String);
begin
  txtEmail.Text := Value;
end;

procedure TContactFrame.SetID(const Value: Integer);
begin
  FID := Value;
end;

procedure TContactFrame.SubscribeMessages;
begin
  DMMain.MsgManager.SubscribeToMessage( TContactDblClicked, procedure( const Sender: TObject;const Msg: TMessage)
                                                            var ContactDblClick : TContactDblClicked;
                                                            begin
                                                              ContactDblClick := TContactDblClicked( Msg );
                                                              ContactName := ContactDblClick.Value.Name;
                                                              Email := ContactDblClick.Value.Email;
                                                              ID := ContactDblClick.Value.Id;
                                                            end);
end;

end.
